# Installing Plaso on Ubuntu

### Ubuntu 18.04 LTS

To install plaso from the GIFT Personal Package Archive (PPA) add the [GIFT PPA](https://launchpad.net/~gift):

```
sudo add-apt-repository ppa:gift/stable
```

Update and install plaso:

```
sudo apt-get update
sudo apt-get install plaso-tools
```

### SANS Investigative Forensic Toolkit (SIFT) Workstation

SIFT workstation version 3 is currently using Ubuntu 16.04 and therefore currently not supported by the GIFT PPA.
